==> everycomp-1.20-2.7.30-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/stylish_stiles/StylishStilesModule.java <==
package net.mehvahdjukaar.every_compat.modules.stylish_stiles;

import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodTypeRegistry;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_2248;
import net.minecraft.class_3481;
import net.minecraft.class_7706;
import net.minecraft.class_7924;
import net.weaverfever.stylishstiles.block.custom.Stile;

import java.util.function.Supplier;

//SUPPORT: v1.1.1+
public class StylishStilesModule extends SimpleModule {
    public final SimpleEntrySet<WoodType, class_2248> STILE;

    public StylishStilesModule(String modId) {
        super(modId, "ss");

        //noinspection DataFlowIssue
        STILE = SimpleEntrySet.builder(WoodType.class, "stile",
                        getModBlock("oak_stile"), () -> WoodTypeRegistry.OAK_TYPE,
                        w -> registerIfFence(w, () -> new Stile(Utils.copyPropertySafe(w.getBlockOfThis("fence"))))
        )
                .addModelTransform(m -> m.addModifier((s, id, w) -> {
                    if (w.getNamespace().equals("tfc")) {
                        return s.replace("\"model\": \"minecraft:block/oak_fence_side\"",
                                "\"model\": \"" + w.getNamespace() + ":block/wood/planks/" + w.getTypeName() + "_fence_side\"");
                    }
                    else {
                        return s.replace("\"model\": \"minecraft:block/oak_fence_side\"",
                                "\"model\": \"" + w.getNamespace() + ":block/" + w.getTypeName() + "_fence_side\"");
                    }
                }))
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_17619, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .setTabKey(class_7706.field_40195)
                .defaultRecipe()
                .build();
        this.addEntry(STILE);
    }

    // Is fence available, then register. Otherwise, will not register
    private <B extends class_2248> B registerIfFence(WoodType woodType, Supplier<B> supplier) {
        if (woodType.getBlockOfThis("fence") != null) {
            return supplier.get();
        }
        return null;
    }

}

==> everycomp-1.20-2.9.10-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/stylish_stiles/StylishStilesModule.java <==
package net.mehvahdjukaar.every_compat.modules.stylish_stiles;

import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_2248;
import net.minecraft.class_3481;
import net.minecraft.class_7706;
import net.minecraft.class_7924;
import net.weaverfever.stylishstiles.block.custom.Stile;

import java.util.function.Supplier;

//SUPPORT: v1.1.1+
public class StylishStilesModule extends SimpleModule {
    public final SimpleEntrySet<WoodType, class_2248> STILE;

    public StylishStilesModule(String modId) {
        super(modId, "ss");

        //noinspection DataFlowIssue
        STILE = SimpleEntrySet.builder(WoodType.class, "stile",
                        getModBlock("oak_stile"), () -> VanillaWoodTypes.OAK,
                        w -> registerIfFence(w, () -> new Stile(Utils.copyPropertySafe(w.getBlockOfThis("fence"))))
        )
                .addModelTransform(m -> m.addModifier((s, id, w) -> {
                    if (w.getNamespace().equals("tfc")) {
                        return s.replace("\"model\": \"minecraft:block/oak_fence_side\"",
                                "\"model\": \"" + w.getNamespace() + ":block/wood/planks/" + w.getTypeName() + "_fence_side\"");
                    }
                    else {
                        return s.replace("\"model\": \"minecraft:block/oak_fence_side\"",
                                "\"model\": \"" + w.getNamespace() + ":block/" + w.getTypeName() + "_fence_side\"");
                    }
                }))
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(class_3481.field_17619, class_7924.field_41254)
                .addTag(class_3481.field_16584, class_7924.field_41254)
                .setTabKey(class_7706.field_40195)
                .defaultRecipe()
                .build();
        this.addEntry(STILE);
    }

    // Is fence available, then register. Otherwise, will not register
    private <B extends class_2248> B registerIfFence(WoodType woodType, Supplier<B> supplier) {
        if (woodType.getBlockOfThis("fence") != null) {
            return supplier.get();
        }
        return null;
    }

}
